/*
 * Copyright 2021-2022 Xilinx, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef SYS_MUTEX_H__
#define SYS_MUTEX_H__

/*
 * These IDs should be unique between all masters and ideally match SMIDs allocated in TRM
 */
#if defined(r5_0)
#define SYS_MUTEX_MASTER_ID    0x200
#elif defined(r5_1)
#define SYS_MUTEX_MASTER_ID    0x204
#elif defined(a72_0)
#define SYS_MUTEX_MASTER_ID    0x264
#elif defined(a72_1)
#define SYS_MUTEX_MASTER_ID    0x265
#else
#error Unknown processor
#endif

/*
 * This macro is inserted in premain() so that apps do not
 * print on console until PLM is done
 */
#define WAIT_FOR_PLM_DONE() \
    while(0 == (*(volatile uint32_t*)0xF1110000 & 0x10)) { \
        ; \
    }

/*
 * Grab system mutex #0
 * Spin until it is becomes free
 */
void GrabSysMutex(void);

/*
 * Release previously grabbed system mutex #0
 */
void ReleaseSysMutex(void);

#endif  /* SYS_MUTEX_H__ */
